==> openshift-model-storageversionmigrator-6.1.0-sources.jar: io/fabric8/openshift/api/model/storageversionmigrator/v1alpha1/StorageVersionMigrationSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StorageVersionMigrationSpecFluentImpl<A extends StorageVersionMigrationSpecFluent<A>> extends BaseFluent<A> implements StorageVersionMigrationSpecFluent<A>{
  public StorageVersionMigrationSpecFluentImpl() {
  }
  public StorageVersionMigrationSpecFluentImpl(StorageVersionMigrationSpec instance) {
    this.withContinueToken(instance.getContinueToken()); 
    this.withResource(instance.getResource()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String continueToken;
  private GroupVersionResourceBuilder resource;
  private Map<String,Object> additionalProperties;
  public String getContinueToken() {
    return this.continueToken;
  }
  public A withContinueToken(String continueToken) {
    this.continueToken=continueToken; return (A) this;
  }
  public Boolean hasContinueToken() {
    return this.continueToken != null;
  }
  
  /**
   * This method has been deprecated, please use method buildResource instead.
   * @return The buildable object.
   */
  @Deprecated
  public GroupVersionResource getResource() {
    return this.resource!=null ?this.resource.build():null;
  }
  public GroupVersionResource buildResource() {
    return this.resource!=null ?this.resource.build():null;
  }
  public A withResource(GroupVersionResource resource) {
    _visitables.get("resource").remove(this.resource);
    if (resource!=null){ this.resource= new GroupVersionResourceBuilder(resource); _visitables.get("resource").add(this.resource);} else { this.resource = null; _visitables.get("resource").remove(this.resource); } return (A) this;
  }
  public Boolean hasResource() {
    return this.resource != null;
  }
  public A withNewResource(String group,String resource,String version) {
    return (A)withResource(new GroupVersionResource(group, resource, version));
  }
  public StorageVersionMigrationSpecFluent.ResourceNested<A> withNewResource() {
    return new StorageVersionMigrationSpecFluentImpl.ResourceNestedImpl();
  }
  public StorageVersionMigrationSpecFluent.ResourceNested<A> withNewResourceLike(GroupVersionResource item) {
    return new StorageVersionMigrationSpecFluentImpl.ResourceNestedImpl(item);
  }
  public StorageVersionMigrationSpecFluent.ResourceNested<A> editResource() {
    return withNewResourceLike(getResource());
  }
  public StorageVersionMigrationSpecFluent.ResourceNested<A> editOrNewResource() {
    return withNewResourceLike(getResource() != null ? getResource(): new GroupVersionResourceBuilder().build());
  }
  public StorageVersionMigrationSpecFluent.ResourceNested<A> editOrNewResourceLike(GroupVersionResource item) {
    return withNewResourceLike(getResource() != null ? getResource(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StorageVersionMigrationSpecFluentImpl that = (StorageVersionMigrationSpecFluentImpl) o;
    if (continueToken != null ? !continueToken.equals(that.continueToken) :that.continueToken != null) return false;
    if (resource != null ? !resource.equals(that.resource) :that.resource != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(continueToken,  resource,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (continueToken != null) { sb.append("continueToken:"); sb.append(continueToken + ","); }
    if (resource != null) { sb.append("resource:"); sb.append(resource + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ResourceNestedImpl<N> extends GroupVersionResourceFluentImpl<StorageVersionMigrationSpecFluent.ResourceNested<N>> implements StorageVersionMigrationSpecFluent.ResourceNested<N>,Nested<N>{
    ResourceNestedImpl(GroupVersionResource item) {
      this.builder = new GroupVersionResourceBuilder(this, item);
    }
    ResourceNestedImpl() {
      this.builder = new GroupVersionResourceBuilder(this);
    }
    GroupVersionResourceBuilder builder;
    public N and() {
      return (N) StorageVersionMigrationSpecFluentImpl.this.withResource(builder.build());
    }
    public N endResource() {
      return and();
    }
    
  }
  
}

==> openshift-model-storageversionmigrator-6.7.2-sources.jar: io/fabric8/openshift/api/model/storageversionmigrator/v1alpha1/StorageVersionMigrationSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StorageVersionMigrationSpecFluentImpl<A extends StorageVersionMigrationSpecFluent<A>> extends BaseFluent<A> implements StorageVersionMigrationSpecFluent<A>{
  public StorageVersionMigrationSpecFluentImpl() {
  }
  public StorageVersionMigrationSpecFluentImpl(StorageVersionMigrationSpec instance) {
    if (instance != null) {
      this.withContinueToken(instance.getContinueToken());
      this.withResource(instance.getResource());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String continueToken;
  private GroupVersionResourceBuilder resource;
  private Map<String,Object> additionalProperties;
  public String getContinueToken() {
    return this.continueToken;
  }
  public A withContinueToken(String continueToken) {
    this.continueToken=continueToken; return (A) this;
  }
  public Boolean hasContinueToken() {
    return this.continueToken != null;
  }
  
  /**
   * This method has been deprecated, please use method buildResource instead.
   * @return The buildable object.
   */
  @Deprecated
  public GroupVersionResource getResource() {
    return this.resource!=null ?this.resource.build():null;
  }
  public GroupVersionResource buildResource() {
    return this.resource!=null ?this.resource.build():null;
  }
  public A withResource(GroupVersionResource resource) {
    _visitables.get("resource").remove(this.resource);
    if (resource!=null){ this.resource= new GroupVersionResourceBuilder(resource); _visitables.get("resource").add(this.resource);} else { this.resource = null; _visitables.get("resource").remove(this.resource); } return (A) this;
  }
  public Boolean hasResource() {
    return this.resource != null;
  }
  public A withNewResource(String group,String resource,String version) {
    return (A)withResource(new GroupVersionResource(group, resource, version));
  }
  public StorageVersionMigrationSpecFluentImpl.ResourceNested<A> withNewResource() {
    return new StorageVersionMigrationSpecFluentImpl.ResourceNestedImpl();
  }
  public StorageVersionMigrationSpecFluentImpl.ResourceNested<A> withNewResourceLike(GroupVersionResource item) {
    return new StorageVersionMigrationSpecFluentImpl.ResourceNestedImpl(item);
  }
  public StorageVersionMigrationSpecFluentImpl.ResourceNested<A> editResource() {
    return withNewResourceLike(getResource());
  }
  public StorageVersionMigrationSpecFluentImpl.ResourceNested<A> editOrNewResource() {
    return withNewResourceLike(getResource() != null ? getResource(): new GroupVersionResourceBuilder().build());
  }
  public StorageVersionMigrationSpecFluentImpl.ResourceNested<A> editOrNewResourceLike(GroupVersionResource item) {
    return withNewResourceLike(getResource() != null ? getResource(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StorageVersionMigrationSpecFluentImpl that = (StorageVersionMigrationSpecFluentImpl) o;
    if (!java.util.Objects.equals(continueToken, that.continueToken)) return false;

    if (!java.util.Objects.equals(resource, that.resource)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(continueToken,  resource,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (continueToken != null) { sb.append("continueToken:"); sb.append(continueToken + ","); }
    if (resource != null) { sb.append("resource:"); sb.append(resource + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ResourceNestedImpl<N> extends GroupVersionResourceFluentImpl<StorageVersionMigrationSpecFluentImpl.ResourceNested<N>> implements StorageVersionMigrationSpecFluentImpl.ResourceNested<N>,Nested<N>{
    ResourceNestedImpl(GroupVersionResource item) {
      this.builder = new GroupVersionResourceBuilder(this, item);
    }
    ResourceNestedImpl() {
      this.builder = new GroupVersionResourceBuilder(this);
    }
    GroupVersionResourceBuilder builder;
    public N and() {
      return (N) StorageVersionMigrationSpecFluentImpl.this.withResource(builder.build());
    }
    public N endResource() {
      return and();
    }
    
  }
  
}
